logEvent method
Useful function to log an event without using the analytics directly
Implementation
void logEvent(String name, {Map<String, dynamic>? properties, List<Type>? sendTo}) =>
analytics.logEvent(name, sendTo, properties: properties);
Useful function to log an event without using the analytics directly
void logEvent(String name, {Map<String, dynamic>? properties, List<Type>? sendTo}) =>
analytics.logEvent(name, sendTo, properties: properties);